@@ -22,10 +22,11 @@ from signal import signal
 from typing import Callable, Dict
 from urllib.parse import parse_qsl
 
+import aiohttp
 import aiohttp_cors
 import firefly.domain as ffd
 import websockets
-from aiohttp import web
+from aiohttp import web, BodyPartReader
 from firefly import TypeOfMessage
 from firefly.domain.entity.messaging.http_response import HttpResponse
 
@@ -119,6 +120,23 @@ class WebServer(ffd.SystemBusAware, ffd.LoggerAware):
 
     def _request_handler_generator(self, msg: TypeOfMessage = None):
         async def _handle_request(request: web.Request):
+            multipart = False
+            request_data = {}
+            if 'multipart/form-data' in request.headers.get('Content-Type', ''):
+                multipart = True
+                reader = await request.multipart()
+                while True:
+                    part = await reader.next()
+                    if part is None:
+                        break
+                    if part.filename:
+                        request_data[part.name] = ffd.File(
+                            name=part.filename,
+                            content=await part.text()
+                        )
+                    else:
+                        request_data[part.name] = await part.text()
+
             self.debug('Got a request -----------------------')
             self.debug(request.headers)
             self.debug(await request.text())
@@ -136,9 +154,12 @@ class WebServer(ffd.SystemBusAware, ffd.LoggerAware):
                     params.update(request.query)
                     message = self._message_factory.query(message_name, None, params)
                 else:
-                    text = await request.text()
-                    if text and len(text):
-                        params.update(self._serializer.deserialize(text))
+                    if multipart:
+                        params.update(request_data)
+                    else:
+                        text = await request.text()
+                        if text and len(text):
+                            params.update(self._serializer.deserialize(text))
                     message = self._message_factory.command(message_name, params)
             else:
                 if msg is not None:
@@ -231,7 +252,6 @@ class WebServer(ffd.SystemBusAware, ffd.LoggerAware):
                 'content_type': request.content_type,
                 'content_length': request.content_length,
                 'query': dict(request.query),
-                'post': dict(await request.post()),
                 'url': request._message.url,
             }
         }
